@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import io
 import re
 import sys
@@ -35,12 +37,14 @@ def sanitize(value):
     return value
 
 
-def output_mapper(obj, labels=None, output_mappings=None):
+def output_mapper(obj, labels=None, output_mappings=None, exclude_fields=None):
+    if exclude_fields is None:
+        exclude_fields = set()
     mapped_obj = {}
     labels = labels or {}
     output_mappings = output_mappings or {}
     for header, label in labels.items():
-        if header in output_mappings and header in obj:
+        if header in output_mappings:
             mapped_obj[label] = sanitize(output_mappings[header](obj))
         elif header in obj:
             mapped_obj[label] = sanitize(obj[header])
