@@ -6,6 +6,8 @@ import sys
 from django.apps import apps
 from django.db.utils import OperationalError
 from django.db.utils import ProgrammingError
+from sqlalchemy.exc import OperationalError as SQLAlchemyOperationalError
+from sqlalchemy.exc import ProgrammingError as SQLAlchemyProgrammingError
 
 from .conf import KOLIBRI_HOME
 from .conf import OPTIONS
@@ -116,6 +118,29 @@ def check_database_is_migrated():
         raise DatabaseInaccessible(db_exception=e)
 
 
+def ensure_job_tables_created():
+    from kolibri.core.tasks.main import job_storage
+    from kolibri.core.tasks.main import scheduler
+
+    try:
+        job_storage.test_table_readable()
+    except (SQLAlchemyOperationalError, SQLAlchemyProgrammingError):
+        logger.warning("Database table for job storage was not accessible, recreating.")
+        job_storage.recreate_tables()
+    except Exception as e:
+        raise DatabaseInaccessible(db_exception=e)
+
+    try:
+        scheduler.test_table_readable()
+    except (SQLAlchemyOperationalError, SQLAlchemyProgrammingError):
+        logger.warning(
+            "Database table for scheduled jobs was not accessible, recreating."
+        )
+        scheduler.recreate_tables()
+    except Exception as e:
+        raise DatabaseInaccessible(db_exception=e)
+
+
 def check_default_options_exist():
     options_path = os.path.join(KOLIBRI_HOME, "options.ini")
     if not os.path.exists(options_path):
